# ---------------------------------------------------------
# An animated fish demo, showing the use of inline color images
# on the canvas widget. Created by Hattie Schroeder, 1997. 
#
#  Copyright (c) 1997 Eolas Technologies Inc.
#  Freely modifiable/redistributable under the "Standard Tcl License"
#  See http://www.eolas.com/tcl/license.txt for details
# ---------------------------------------------------------


# -------------------------------------------
#  Creates each fish by creating an image and
#  image canvas object
# -------------------------------------------
 
proc make_fish { fish x y tag } {

set im [image create photo -data $fish \
		-format GIF -gamma 1 \
		-height 56 -width 79 -palette 5/5/4]
.c create image $x $y -image $im \
		-tag $tag -anchor center
}

# -------------------------------------------------
# Moves a fish from a particular starting point with 
# a specific time period.
# --------------------------------------------------



proc move_fish { fishtag period place data x1 y1 } {
if {[string match *r $fishtag]} {
	set x 10 
	} else { 
	set x -10
	}
for {set i 0} {$i < [expr $place *$period/10]} \
		{incr i $period} {
		after $i ".c move $fishtag $x 0"
}

after $i "
	.c delete $fishtag 
	make_fish {$data} $x1 $y1 $fishtag
	move_fish $fishtag $period $place {$data} $x1 $y1
	"
}


# ----------------------------------------------------
# Creates bubbles for specific fish
# ----------------------------------------------------


proc bubble { x y} {
.c create oval $x $y [expr $x+10] [expr $y+10] -outline white -tag bubble$x 
.c create oval $x [expr $y+15] [expr $x+10] [expr $y+25]  -outline white -tag bubble$x 
.c create oval [expr $x+3] [expr $y+30] [expr $x +8] [expr $y +35] -outline white -tag bubble$x 
for {set k 0} {$k < [expr $y * 100/ 5]} {incr k 100} {
	after $k ".c move bubble$x 0 -5"
	}
after $k ".c delete bubble$x"
}

proc bubbling { x y period } {
for {set i 0} {$i < [expr $period * $x] } {incr i  [expr $period * 15] } {
after $i "bubble $x $y" 
incr x -150
} 
}


# ----------------------------------------------------
# Specify image data
# ----------------------------------------------------


set leaf {
R0lGODlhEADIAPcAAAAAAADnAISEAP//////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////yH5BAEAAAAALAAAAAAQAMgA
AAj+AAEIHEiwoEABBhMeRKiwoACGDQc+jEhwIsWFFzFmtHjxIcSIHjMC4EgxZEeTJUk29PhRIcuN
KFe+BMmypcOaNHHKnOmypk2JPn+ODLpTp8GgQpH+VGqTaUKlT5FGJXpU6lSjN3321HqVZ1WsWb2G
jTlWZdmcZM8WNTs2Zdq2boVWfBv2JNu6ce3KBXp3bl++exf+FRx46GDDhcVe1cs4r2O0MAsbjkzZ
bmW3l3Nm3rl5a+epn7+GztoY8uOtg8F+Ta3YL13Cfal2jc11dlLZZdlCXa0asWqnuckybTk8eMzh
EJEnRw54t3KGz2FDfY6Qum+n1rNH1678+vTt4Lttc2c+vnh57OHJpze/Hr349t/fy1c/n3199/Tz
2y/unWr0/lx1J51sAgJ4HH8DYsVcc7gtmKBwwDEIVoQSpkXhg03t5lpvGm7YmlW80QVicKi15t1a
tPUmHVp/1dZVXIGpCFhpRdGYUACvDRQQAAA7
}

set leaf2 {
R0lGODlhGAAsAfcAAAAAAAAAMwAAZgAAmQAAzAAA/zMAADMAMzMAZjMAmTMAzDMA/2YAAGYAM2YA
ZmYAmWYAzGYA/5kAAJkAM5kAZpkAmZkAzJkA/8wAAMwAM8wAZswAmcwAzMwA//8AAP8AM/8AZv8A
mf8AzP8A/wAzAAAzMwAzZgAzmQAzzAAz/zMzADMzMzMzZjMzmTMzzDMz/2YzAGYzM2YzZmYzmWYz
zGYz/5kzAJkzM5kzZpkzmZkzzJkz/8wzAMwzM8wzZswzmcwzzMwz//8zAP8zM/8zZv8zmf8zzP8z
/wBmAABmMwBmZgBmmQBmzABm/zNmADNmMzNmZjNmmTNmzDNm/2ZmAGZmM2ZmZmZmmWZmzGZm/5lm
AJlmM5lmZplmmZlmzJlm/8xmAMxmM8xmZsxmmcxmzMxm//9mAP9mM/9mZv9mmf9mzP9m/wCZAACZ
MwCZZgCZmQCZzACZ/zOZADOZMzOZZjOZmTOZzDOZ/2aZAGaZM2aZZmaZmWaZzGaZ/5mZAJmZM5mZ
ZpmZmZmZzJmZ/8yZAMyZM8yZZsyZmcyZzMyZ//+ZAP+ZM/+ZZv+Zmf+ZzP+Z/wDMAADMMwDMZgDM
mQDMzADM/zPMADPMMzPMZjPMmTPMzDPM/2bMAGbMM2bMZmbMmWbMzGbM/zxPAJnMM5nMZpnMmZnM
zJnM/8zMAMzMM8zMZszMmczMzMzM///MAP/MM//MZv/Mmf/MzP/M/wD/AAD/MwD/ZgD/mQD/zAD/
/zP/ADP/MzP/ZjP/mTP/zDP//2b/AGb/M2b/Zmb/mWb/zGb//5n/AJn/M5n/Zpn/mZn/zJn//8z/
AMz/M8z/Zsz/mcz/zMz/////AP//M///Zv//mf//zP///wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAAAALAAAAAAYACwB
AAj+AAEIHEiwoMGDCBMqXMiwIUFRDhGKghjx4USKFQFcnJhR40aMDj9yjChyZMOSJhmiBJlwZcqW
Lk/GXOjypcGaNgviZKlzJ0ycCnfytAhUok+jR28KHeoxaU+hB5fmlDqUatSlSJ0S1SrQqlKoV8F+
5dpV7NiaP4uGRZt2Zla3a+GeRUmTbVC7bUuqlPtWpEy6f/UG9jv4Y0jAhw1XFLx4Y8emTP92pHhx
8sCcdS9Pxhj55+OymPeGrlt5c+mMhBs7Rp068WqSrQuPjjt7bue+t2nnts1aMWzfrl/Lrr1VuOjY
dxkP3w0aeXLnuE8fB05a+XPouok3p37deHfsxcH+X+abXfp383m9R9dOvjxzyNzTa4evfr3q+PLv
10/fez/u/uhN9954/vX1GH7VDUjgfMV9VmBynzUVYYCwReiRhQwqhaGCPW1ooUYOdhUihh9mSNSE
Jjbn4INPsRiegtYlSGF5v4n34owLIiZfgWTluNJ52GG1nnNetcgVVSwhCZKSSyp5o1pMcsbkdlZF
yZGVEGFJH5Zcdunll2CGKeaYZJZpZkxWUinklk45+aRcSNpGnlRDIqimeD36aCNeO76no4Aw2jiX
aSna2daBOD6HaKI6EYiao4tBSpKkIVEqE2isYdrYQ5lqppqnv4GamKiSifipqaGiOqqqga2YImSJ
rhZqKG2EMmpkhjHK6GJ7ctrKZ53LEfere7Wp1Weied4Jnlm92snsrX9Cm6ue0VI7LZvXrtksgtpK
Wy2209JJLH7ibktuuW/mWmS6RKJrbbXrvquuu8rCSy+40cbp7Y/75quvvH+6CbB1AtfL78CxFYxv
wAVPiXBrDht88MI6RkyxchZn3HDBAQEAOw==
}



set leaf3 {
R0lGODlhegDIAPcAAAAAAAAAMwAAZgAAmQAAzAAA/zMAADMAMzMAZjMAmTMAzDMA/2YAAGYAM2YA
ZmYAmWYAzGYA/5kAAJkAM5kAZpkAmZkAzJkA/8wAAMwAM8wAZswAmcwAzMwA//8AAP8AM/8AZv8A
mf8AzP8A/wAzAAAzMwAzZgAzmQAzzAAz/zMzADMzMzMzZjMzmTMzzDMz/2YzAGYzM2YzZmYzmWYz
zGYz/5kzAJkzM5kzZpkzmZkzzJkz/8wzAMwzM8wzZswzmcwzzMwz//8zAP8zM/8zZv8zmf8zzP8z
/wBmAABmMwBmZgBmmQBmzABm/zNmADNmMzNmZjNmmTNmzDNm/2ZmAGZmM2ZmZmZmmWZmzGZm/5lm
AJlmM5lmZplmmZlmzJlm/8xmAMxmM8xmZsxmmcxmzMxm//9mAP9mM/9mZv9mmf9mzP9m/wCZAACZ
MwCZZgCZmQCZzACZ/zOZADOZMzOZZjOZmTOZzDOZ/2aZAGaZM2aZZmaZmWaZzGaZ/5mZAJmZM5mZ
ZpmZmZmZzJmZ/8yZAMyZM8yZZsyZmcyZzMyZ//+ZAP+ZM/+ZZv+Zmf+ZzP+Z/wDMAADMMwDMZgDM
mQDMzADM/zPMADPMMzPMZjPMmTPMzDPM/2bMAGbMM2bMZmbMmWbMzGbM/5nMAJnMM5nMZpnMmZnM
zJnM/8zMAMzMM8zMZszMmczMzMzM///MAP/MM//MZv/Mmf/MzP/M/wD/AAD/MwD/ZgD/mQD/zAD/
/zP/ADP/MzP/ZjP/mTP/zDP//2b/AGb/M2b/Zmb/mWb/zGb//5n/AJn/M5n/Zpn/mZn/zJn//8z/
AMz/M8z/Zsz/mcz/zMz/////AP//M///Zv//mf//zP///wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAAAALAAAAAB6AMgA
AAj+AAEIHEiwoMGDCBMqXMiwocOHECNKnEixosWLGDNq3IjRj8ePHjmKHNkx5MGPJEGqXGmS5EWW
fhTG3AizJkqXFW3KnPnSpk6cFH3yPGlRqE+gQYXKTGq0JlKJMY0uhdj06FOqAqVObVj151WHQ7Um
HDq2q9OvXAuKHcvQLEy0adUqbbvTrUq4cQmuZYuwKoCzeLfqnUvXoN+/bwPzPWk1b1atXhXLJTs5
sWPESiNLHni3r+aFPAl/3oy5peHRfL0SJj34pmfLYFdWRk2682uWEe2CZF3XNGPcXHX75v17+Ozd
bYVTJn7a9W3bxe0yj+38efXWsKcXRd6b+/GoIZf+a8/tvSz0x7hRih//8Lz56k6Rr2ef/Pp7sm87
z6ffnarv/PrxN5FsOaVH4F8CkucedXdZtl+CzZUXnIEHIgghg/Z1t1t2D17I2YIahsehh+1JGKKI
wOlVknFwgWgdihVy1pOJLbL4IngpqjVjhgLGl52M29HYI4G0dfgiieg1CBhRTAlJH4A5MglVlAlC
GWNfU1I55GGFnajlk2aBdd9eWzbVXnRcQthVbt+dZSRzaYr5oVg2shennKUd5aSdZkKVpFU8gkkm
hpntOR5kykl1ZZWJNjpnoII22mebSGInqaSVjnnpmpm2uemdlYKq6aBI+vXplyT++Oepb0a6Iav+
qGYKq5WtejjrgbWmeqttuV64K3S9qvkrZcEyeiuWnYI2q2DJ3igdns3CGe2h005XbLUiXYstTdvy
pm23HYFbm7ibfUtuUOcqZmSswpKKrLOLuupWl3lyWqaj7yZ6L6ZE8cvnspbqe+ivj25q7bAEe4tw
wqwtfCxx8frnMJyseipdxIENW7CLEdaJl8Nh+QsxyAZrR/Kl8p48b8oqi0pxy5PKSnK6G38KJM0d
45sVzi3yjJa5Pl8WtEtAD82s0SMVjbSUMguskdI/o/x0sgCj26nGbFLNMLRXY01v1wh/3bRqTjOt
dcz1oq3itMLVXGS1joZpNtjKua0l1BlLfSf+3nlLnXaMfPft92qBC26waN3Cuiqv4C6rmsXufvVw
fAGXXaPjPiqu7rEtS8Z555srDnPhyp7698ShHz466V6ubnnUKi8usuELV64z5LSNuvWOy5U8oet1
53w7ocA3hrtuQI3e+uw0xb4880/PXN/D2aL+O/Xchl1i7VOfDn3pFNr80vFyD7gkvLkL7b3L2z/7
rNVopt8k8uuze/TLApef9b/+2sv1wOJjn2GMZTrZcUxHBKxY/f4HwMmd7137wpyqEJjAXZ1ObPzT
2APX1q7aTXBnvppZrFgXPRFGjIQZ6dz5UFhCkHmPg2Mj2JJYmLSJOShaJmQcDl1IJLjl0CRYNMTJ
D2cSxOR5cEPnOpmFkuhCnDWRZ9pDGvaWpsClxU9/VlxREWm2xSRmMSVfzFYYOdJFL46xe2cMVxrV
uMaitHF8b8xJHOdIR4jV8Y54zKMe98jHoAUEAAA7
}

set leaf4 {
R0lGODlhGAAsAfcAAAAAAAAAMwAAZgAAmQAAzAAA/zMAADMAMzMAZjMAmTMAzDMA/2YAAGYAM2YA
ZmYAmWYAzGYA/5kAAJkAM5kAZpkAmZkAzJkA/8wAAMwAM8wAZswAmcwAzMwA//8AAP8AM/8AZv8A
mf8AzP8A/wAzAAAzMwAzZgAzmQAzzAAz/zMzADMzMzMzZjMzmTMzzDMz/2YzAGYzM2YzZmYzmWYz
zGYz/5kzAJkzM5kzZpkzmZkzzJkz/8wzAMwzM8wzZswzmcwzzMwz//8zAP8zM/8zZv8zmf8zzP8z
/wBmAABmMwBmZgBmmQBmzABm/zNmADNmMzNmZjNmmTNmzDNm/2ZmAGZmM2ZmZmZmmWZmzGZm/5lm
AJlmM5lmZplmmZlmzJlm/8xmAMxmM8xmZsxmmcxmzMxm//9mAP9mM/9mZv9mmf9mzP9m/wCZAACZ
MwCZZgCZmQCZzACZ/zOZADOZMzOZZjOZmTOZzDOZ/2aZAGaZM2aZZmaZmWaZzGaZ/5mZAJmZM5mZ
ZpmZmZmZzJmZ/8yZAMyZM8yZZsyZmcyZzMyZ//+ZAP+ZM/+ZZv+Zmf+ZzP+Z/wDMAADMMwDMZgDM
mQDMzADM/zPMADPMMzPMZjPMmTPMzDPM/2bMAGbMM2bMZmbMmWbMzGbM/2WGAJnMM5nMZpnMmZnM
zJnM/8zMAMzMM8zMZszMmczMzMzM///MAP/MM//MZv/Mmf/MzP/M/wD/AAD/MwD/ZgD/mQD/zAD/
/zP/ADP/MzP/ZjP/mTP/zDP//2b/AGb/M2b/Zmb/mWb/zGb//5n/AJn/M5n/Zpn/mZn/zJn//8z/
AMz/M8z/Zsz/mcz/zMz/////AP//M///Zv//mf//zP///wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAAAALAAAAAAYACwB
AAj+AAEIHEiwoMGDCBMqXGhQFMOFohw+RBgx4sSGFSVeFJjR4kYAHT1eDCnyIcmSEE+OPImSIkuN
Cl/CTChz5sGaNgviTFmTp8yYO2kGFdqTaNGbOFsOTJqTI1OXTzFG1cm0aVWoQ6kmxZqV4FWkW8F2
9RpW7E+uL4EeNctS7Vm0Kt229RlXLkmGa43exZvW5Fy+del2nNjX717CIT8eXlnx49LGjkEqRSyx
KdCljjVOjvk4slPLPj1njDw482jFpTcmVr2a8WnXkCmnNvxadmzatwHX1p2b92a4rFv77q2XONzf
WoXbNc6WefLZy52TXRwd+ePA1WHvzi5YefPt36X+f8Z+3Pp47+VBT6deHHx47eKvoy8PX/3z+PLd
Aw+ufz981P2hZVqAZpFGYIEDmieVfVB5JhmDDYoGoUsOSlahghQ6iCFSF1YIEkceTkjRhSJKpeGG
yRmI330lstcdgNB1h+FfMiqYV3jijcWii/nRuOBbPxYWJJA9EnneWFXlluRtS5bUJExPavZkkVFF
aZGVDmH54JRYdunll2CGKeaYZJZp5mhabrkklVlNud5URyKZJI48fkWnfjq+Sd6QMdJpW5/Hwbhi
nIKWeJ6KKB6KqISJKjogZsFBypiklFFqmKWAOQWgpqqRpZinnX72qaihPjiqqaUO+iGpI13HqKGH
472KqKHz2VVoi7X6VyOEQrZ3oJF+Dvdrr3cKG2CebPZX1p2/Lctnrs7uWCuc0k4bbbKAqkkstu7Z
We183uq5rbbjhhvntnM+u2e636LHrrjomktuvNSe6+O8xK7Zrnf6cktdk/sqBzC8RA7sr8D92iuk
mwovbDC+QDIMscMJS2zxwxcvGRAAADs=
}

set leaf5  {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}

set leaf6 {
R0lGODlhEADIAPcAAAAAAADnAISEAP//////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////yH5BAEAAAAALAAAAAAQAMgA
AAj+AAEIHEiwoMGDAgUgNChA4UKCDR9CdCgRQMSKFilKvFiR48OGGheCxOhRZMmDIEOiPMlw5EaX
JllOhLky5ceUKgfilJnRJsKdOXvi/Am05lCjPgsCPbmUadOWRaHuRJp05lSpVa1m1RkVK02tPLt6
DSr0K9ibW8/GNKv1Jdu2aMly5TlXbsK3VjvirauX7l2/QvvaDex2cFqle/8aTkw4ruDHbkkC7il5
MOW+lTNj3hyZM1rNnUN/9hyz8mLAh+GutXt0dWG6V4m2Hrs6bOyxQZfKvl13du+0TVUGx/01eEjj
iIf/7mqcY3OKzx1GV6w8ukLrZYdj3z6d+/PsT71uNwevWzxy89q7q/+OPvz68e3Lvz8/Pz37+u7v
64ePXzf5q9P9d1SAAsL0HXX+IXjbeMvNxqCCDiIHlm8SNmiWchNe+FRyYkHI0oYc+ubhboclGOJb
JmZYG1kdThgXbCKq5dqLr0HmWGE2ohVAQAAAOw==
}




set gfish {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}

set gfish_r {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}


set bfish {
R0lGODlhTwA4APcAAAAAAAAAMwAAZgAAmQAAzAAA/zMAADMAMzMAZjMAmTMAzDMA/2YAAGYAM2YA
ZmYAmWYAzGYA/5kAAJkAM5kAZpkAmZkAzJkA/8wAAMwAM8wAZswAmcwAzMwA//8AAP8AM/8AZv8A
mf8AzP8A/wAzAAAzMwAzZgAzmQAzzAAz/zMzADMzMzMzZjMzmTMzzDMz/2YzAGYzM2YzZmYzmWYz
zGYz/5kzAJkzM5kzZpkzmZkzzJkz/8wzAMwzM8wzZswzmcwzzMwz//8zAP8zM/8zZv8zmf8zzP8z
/wBmAABmMwBmZgBmmQBmzABm/zNmADNmMzNmZjNmmTNmzDNm/2ZmAGZmM2ZmZmZmmWZmzGZm/5lm
AJlmM5lmZplmmZlmzJlm/8xmAMxmM8xmZsxmmcxmzMxm//9mAP9mM/9mZv9mmf9mzP9m/wCZAACZ
MwCZZgCZmQCZzACZ/zOZADOZMzOZZjOZmTOZzDOZ/2aZAGaZM2aZZmaZmWaZzGaZ/5mZAJmZM5mZ
ZpmZmZmZzJmZ/8yZAMyZM8yZZsyZmcyZzMyZ//+ZAP+ZM/+ZZv+Zmf+ZzP+Z/wDMAADMMwDMZgDM
mQDMzADM/zPMADPMMzPMZjPMmTPMzDPM/2bMAGbMM2bMZmbMmWbMzGbM/5nMAJnMM5nMZpnMmZnM
zJnM/8zMAMzMM8zMZszMmczMzMzM///MAP/MM//MZv/Mmf/MzP/M/wD/AAD/MwD/ZgD/mQD/zAD/
/zP/ADP/MzP/ZjP/mTP/zDP//2b/AGb/M2b/Zmb/mWb/zGb//5n/AJn/M5n/Zpn/mZn/zJn//8z/
AMz/M8z/Zsz/mcz/zMz/////AP//M///Zv//mf//zP///wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAKwALAAAAABPADgA
AAj+AEmQ+EewoMGDCBMWHKiwocOHCBlCnEiQhBMnEiNmpMjxn8COB+WIvOhEpMmTKE1iBMmyZcqX
ME9ubEkzoZN/MXO+vFlT4cyJJXWmtESUKEqePZN6FDq0aNGUShdy/EiiqdGXT0VmlRnVI0WBWJ1a
CovyKlelP33+C3ryqtm2Y+HCRJsWIcaqZcWGFfv2JNqvInHmdQqTb9yXdb9SDMqWqeOYFP1WTEyw
8ePLkCFKnogXs07COidu9urTs1C+OikLDjw5ocWTF03nlQs5MUrXFwU2vtlZdl85v6EqvN26auyB
Ml/L1nrYZHDhCM8a3L1W5XLa2FNHF5nxI/Xen5/+O2/O3LHHjCa7VzzrWG9Ow+SFgh/p2uJKj5b3
AhfPHPR1+gsNtJF9px3G32P+aXfQRQcRGN54/8EnFFL4UVhhfk1BuNxW+8WHUncWZUQShoMl6Nlv
B1oo4HQkMeXehvEdONOAGJH433vweQhbRLjZeGNMqE3I43A/HvjfRw0SGSGHP344ZIM3uqVjkxpF
tGR2s4UmEFjEGTTjlRpaNSV3EkEn1YJglicmf1aa5JqXUTYXnJSZQenmm5XFiaWawdU1mpdbnshh
kGvGZ9udPjGkHI6EmlhiSpSl11Fshb3FpGxINgRgR/OF6elyqnHHEpdZZnidapXR1Olz/F2qUldc
Dq2qo3gvpncfrPWRVaqp+0mHa2l7GVZpqb9CZCOhumqIKq4+IkieURYWq1CzLj471rLFdoqZsHJI
O6kclApalLctLbocuT2ZO6FK2KLbkLoxhegurvCyNi8AAQEAOw==
}

set bfish_r {
R0lGODlhTwA4APcAAAAAAAAAMwAAZgAAmQAAzAAA/zMAADMAMzMAZjMAmTMAzDMA/2YAAGYAM2YA
ZmYAmWYAzGYA/5kAAJkAM5kAZpkAmZkAzJkA/8wAAMwAM8wAZswAmcwAzMwA//8AAP8AM/8AZv8A
mf8AzP8A/wAzAAAzMwAzZgAzmQAzzAAz/zMzADMzMzMzZjMzmTMzzDMz/2YzAGYzM2YzZmYzmWYz
zGYz/5kzAJkzM5kzZpkzmZkzzJkz/8wzAMwzM8wzZswzmcwzzMwz//8zAP8zM/8zZv8zmf8zzP8z
/wBmAABmMwBmZgBmmQBmzABm/zNmADNmMzNmZjNmmTNmzDNm/2ZmAGZmM2ZmZmZmmWZmzGZm/5lm
AJlmM5lmZplmmZlmzJlm/8xmAMxmM8xmZsxmmcxmzMxm//9mAP9mM/9mZv9mmf9mzP9m/wCZAACZ
MwCZZgCZmQCZzACZ/zOZADOZMzOZZjOZmTOZzDOZ/2aZAGaZM2aZZmaZmWaZzGaZ/5mZAJmZM5mZ
ZpmZmZmZzJmZ/8yZAMyZM8yZZsyZmcyZzMyZ//+ZAP+ZM/+ZZv+Zmf+ZzP+Z/wDMAADMMwDMZgDM
mQDMzADM/zPMADPMMzPMZjPMmTPMzDPM/2bMAGbMM2bMZmbMmWbMzGbM/5nMAJnMM5nMZpnMmZnM
zJnM/8zMAMzMM8zMZszMmczMzMzM///MAP/MM//MZv/Mmf/MzP/M/wD/AAD/MwD/ZgD/mQD/zAD/
/zP/ADP/MzP/ZjP/mTP/zDP//2b/AGb/M2b/Zmb/mWb/zGb//5n/AJn/M5n/Zpn/mZn/zJn//8z/
AMz/M8z/Zsz/mcz/zMz/////AP//M///Zv//mf//zP///wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAKwALAAAAABPADgA
AAj+AP8JHEiwoMGDCBMqXJgwQACGEAmuWfOnosWLGC9GjPhwI8OJFCuGzIhxpEWPBh3+64jSIMiL
JkmKJNkyZc2CL2HKLLnz5sqOIIOCRLhGoFCdPJPSbMnyT8inQQ9O/FeUYsyYTjNizfrn5kOuE50O
lXr0qtazJEP+9PjwZdioLo9ytYi17s6wf1hudCt2atygdJXORCvz5UaVOYWSzTk4MFLBd4tCBAoW
rkTAjxtrdryTrl+FlKGOHSg389zNqDtTXIgYbN/LmE2bJdxZJ2ijeK2KpNoXL+TZkGuLVJswMUyq
uu/+Tiu84j+YxBcnH/78NG3rW7diHKj1s0CguoH+a98MHHpt7mm9k846vrxv7IXHdxWoer5e+eQF
l2/OfybZ2rNBxVlq/QFoH0EB4BcgZ/sVKNxqKSmY1EgUBmedg4EdlKCBSFWYX4MYTtSRXhvW1yGD
g01HoGklFaXXQCUqd2JjT80EooXUIYighDPmN+CFN4qF3EoFxRhfj/D9aFeL2Q314ntHpijblDhC
uV1cDtaoJJUsemalc6Qxxp+WPpb5Y5QnSYShlFu2iSOTEKq5JplJmmlefy5d+KBm7r2Jn0Z5mqQi
c3WeFqSeS+FkqFgm9ukmoZ0Vx56NvBU2oKAsyvflSS8aNSl7yFnpIZ+Z7imTpMlZdZlSmF56XXqW
iUr1qaqrouiqbH9itVB4lBY5aqt2Mmpimgrxyp5kMBq36KOeARhdsbPmiFOqmS35aosRyRUesrCR
eiaim863l3FQEeUtgV8K9axHqb7llLnLroioRuK2pK5i/wE7r7xg+jTtR+5pGqm//mJ2KKIEJwzY
VQJnlPDDuEH5J6AQVxzqxFdarPHGHHfs8ccgh8zQiypxHBAAADs=
}



set ofish {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}

set ofish_r {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}

set rainfish {
R0lGODlhTwA4APcAAAAAAAAAMwAAZgAAmQAAzAAA/zMAADMAMzMAZjMAmTMAzDMA/2YAAGYAM2YA
ZmYAmWYAzGYA/5kAAJkAM5kAZpkAmZkAzJkA/8wAAMwAM8wAZswAmcwAzMwA//8AAP8AM/8AZv8A
mf8AzP8A/wAzAAAzMwAzZgAzmQAzzAAz/zMzADMzMzMzZjMzmTMzzDMz/2YzAGYzM2YzZmYzmWYz
zGYz/5kzAJkzM5kzZpkzmZkzzJkz/8wzAMwzM8wzZswzmcwzzMwz//8zAP8zM/8zZv8zmf8zzP8z
/wBmAABmMwBmZgBmmQBmzABm/zNmADNmMzNmZjNmmTNmzDNm/2ZmAGZmM2ZmZmZmmWZmzGZm/5lm
AJlmM5lmZplmmZlmzJlm/8xmAMxmM8xmZsxmmcxmzMxm//9mAP9mM/9mZv9mmf9mzP9m/wCZAACZ
MwCZZgCZmQCZzACZ/zOZADOZMzOZZjOZmTOZzDOZ/2aZAGaZM2aZZmaZmWaZzGaZ/5mZAJmZM5mZ
ZpmZmZmZzJmZ/8yZAMyZM8yZZsyZmcyZzMyZ//+ZAP+ZM/+ZZv+Zmf+ZzP+Z/wDMAADMMwDMZgDM
mQDMzADM/zPMADPMMzPMZjPMmTPMzDPM/2bMAGbMM2bMZmbMmWbMzGbM/5nMAJnMM5nMZpnMmZnM
zJnM/8zMAMzMM8zMZszMmczMzMzM///MAP/MM//MZv/Mmf/MzP/M/wD/AAD/MwD/ZgD/mQD/zAD/
/zP/ADP/MzP/ZjP/mTP/zDP//2b/AGb/M2b/Zmb/mWb/zGb//5n/AJn/M5n/Zpn/mZn/zJn//8z/
AMz/M8z/Zsz/mcz/zMz/////AP//M///Zv//mf//zP///wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAKwALAAAAABPADgA
AAj+AA38G0iwoMGDAwEoXMiwoUOGCCNKPGhA4ESEDzNqfHixI0WPBDeKHAmypMmRKEmajFgRJEoM
MGPKTAlgpU2DNGXqnLnxJkWLFxvGzLhzp0ifHzsKhUm0qM6eSAkC7Wig6EOnT49GbelRgtWrWIdq
9cn1YtWvDsOKZYiB482pE706Bas2bduMZqeWlSh3rt26S+/iZckA7sSzYekmDix4sEEDDBhINUyQ
gVqmfxezXeu4IOKBe2sCMNAXQ+msjLFm5gzxoEyKYCUjRr0ZcG2eDl3HnPzPAEOBMiuexr3wcmOF
fhsa1HmQreS+w2kjv7zaaG7mk4vDlNDbOObbqlP+W0+t1zeA4AO9Hz8/NLl29Tsl/zRtkbT3zNOl
s4evUz5ogWdJxUB0aOWHWYEG8odBZAdFhoFnA94HXoLfvadgRf71xuCDoEngoHGpWVghhepVVF5h
HP4T2YfUTUhhiPBBlmFvFXEoI4u27bfWeDoe6B2GjwFn44oSviiiiN/9uBdo6U1mWYtIupickjP2
RlCK3UHZ43E8hbclVpHBxRWWsynIZZLulWiYRVj+YyZx+5E4IlZuBldlSzBJ9SZrRcqJoZ1rNjnQ
k3uK596XGAAV3JpCDkSgeoYiWJRuD1LGZpZ7nqnllgihhxCbj0IKnpdfdvrapzVmyieIRpq6m0SA
YxYa6XhZwRogSLKOWiBPFz1ZUq660jZTR4Wt9KZiCLbW601mIqufsofZFGyycq4HbVQYzQpntdYu
hO1Ezj6rmVvfStRUsjkqV65S1c35bG7remQeTfR6G29J9eZ770r56ruvS/3S9C++AaM08E0Fk3vw
SQmrG1VN5TbsMFIABAQAOw==
}

set yfish {
R0lGODlhTwA4APcAAAAAAAAAMwAAZgAAmQAAzAAA/zMAADMAMzMAZjMAmTMAzDMA/2YAAGYAM2YA
ZmYAmWYAzGYA/5kAAJkAM5kAZpkAmZkAzJkA/8wAAMwAM8wAZswAmcwAzMwA//8AAP8AM/8AZv8A
mf8AzP8A/wAzAAAzMwAzZgAzmQAzzAAz/zMzADMzMzMzZjMzmTMzzDMz/2YzAGYzM2YzZmYzmWYz
zGYz/5kzAJkzM5kzZpkzmZkzzJkz/8wzAMwzM8wzZswzmcwzzMwz//8zAP8zM/8zZv8zmf8zzP8z
/wBmAABmMwBmZgBmmQBmzABm/zNmADNmMzNmZjNmmTNmzDNm/2ZmAGZmM2ZmZmZmmWZmzGZm/5lm
AJlmM5lmZplmmZlmzJlm/8xmAMxmM8xmZsxmmcxmzMxm//9mAP9mM/9mZv9mmf9mzP9m/wCZAACZ
MwCZZgCZmQCZzACZ/zOZADOZMzOZZjOZmTOZzDOZ/2aZAGaZM2aZZmaZmWaZzGaZ/5mZAJmZM5mZ
ZpmZmZmZzJmZ/8yZAMyZM8yZZsyZmcyZzMyZ//+ZAP+ZM/+ZZv+Zmf+ZzP+Z/wDMAADMMwDMZgDM
mQDMzADM/zPMADPMMzPMZjPMmTPMzDPM/2bMAGbMM2bMZmbMmWbMzGbM/5nMAJnMM5nMZpnMmZnM
zJnM/8zMAMzMM8zMZszMmczMzMzM///MAP/MM//MZv/Mmf/MzP/M/wD/AAD/MwD/ZgD/mQD/zAD/
/zP/ADP/MzP/ZjP/mTP/zDP//2b/AGb/M2b/Zmb/mWb/zGb//5n/AJn/M5n/Zpn/mZn/zJn//8z/
AMz/M8z/Zsz/mcz/zMz/////AP//M///Zv//mf//zP///wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAKwALAAAAABPADgA
AAj+AP/9CxBAoMGDCBMqXMiwocOHBR9KNBighcWLGC9GnMhx4MCNHQ9WzHgR4UiMIR1aBJnyIEmU
Bl+ubJlQI8uOBWWWjKmzxc2UOz0C/dezBc+iRmkSLflTItKZJ5EqRdl0IcGnGpdiTRoyI8WJV7cK
3DqzK9WqCaM+HUiWIFqFXj9OJGuRbVuuc2G+dUk37NOCFffyZSpYa1u1PXOWfUhSIEHGdDWKVbu3
sUTEd7HahdnQslCFmDMjVewZruXHaSOrNvpYZlOZqd1mBBzZr07HOn/ClhuVtE/Dom8DJwmyJ8LZ
w1cnjzva90vHzmmvxmj7NNbQQXFnXd6XO+vppT/+lsWM/Tb26uChf6b4PPLY3eXJimQZ2jv8++B3
Bjbp03Lt957lF9R+7CFmn2sAxnWgZo4tVWBUCW4V0W6bpcdeXR+pFeF1G2JYoXIiZWdbh2stN5h8
V5mG12YTqkYiV8q5VVN21L1Y1FEKxueajMdx5qOLJEakY243SWWjcS9q5+KKB+Io34vSrYbaiXX9
6J6NR5bYI4Ugepelkak996WY3jlXmnBp1TddiwgiSWV2YXo1nZPIobklZwsJqGBi3OUZnop60lkj
hTMq2JmeMApHpp94HiqgR0j+WSicDCEqHoJaEegopZtKCeV7hQ3XUX6PYXfUqI06JaWZPlaEKqdI
EKnWGqYOvuqhWX2xOt6tqsJ6GV2QctmSoS0N6WF9RE3FK03GvmnUsq8qFadkjdYprVbXgoZcYCDJ
Bq1Z2TY05ViFhkvuPwEBADs=
}

set rainfish_r {
R0lGODlhTwA4APcAAAAAAAAAMwAAZgAAmQAAzAAA/zMAADMAMzMAZjMAmTMAzDMA/2YAAGYAM2YA
ZmYAmWYAzGYA/5kAAJkAM5kAZpkAmZkAzJkA/8wAAMwAM8wAZswAmcwAzMwA//8AAP8AM/8AZv8A
mf8AzP8A/wAzAAAzMwAzZgAzmQAzzAAz/zMzADMzMzMzZjMzmTMzzDMz/2YzAGYzM2YzZmYzmWYz
zGYz/5kzAJkzM5kzZpkzmZkzzJkz/8wzAMwzM8wzZswzmcwzzMwz//8zAP8zM/8zZv8zmf8zzP8z
/wBmAABmMwBmZgBmmQBmzABm/zNmADNmMzNmZjNmmTNmzDNm/2ZmAGZmM2ZmZmZmmWZmzGZm/5lm
AJlmM5lmZplmmZlmzJlm/8xmAMxmM8xmZsxmmcxmzMxm//9mAP9mM/9mZv9mmf9mzP9m/wCZAACZ
MwCZZgCZmQCZzACZ/zOZADOZMzOZZjOZmTOZzDOZ/2aZAGaZM2aZZmaZmWaZzGaZ/5mZAJmZM5mZ
ZpmZmZmZzJmZ/8yZAMyZM8yZZsyZmcyZzMyZ//+ZAP+ZM/+ZZv+Zmf+ZzP+Z/wDMAADMMwDMZgDM
mQDMzADM/zPMADPMMzPMZjPMmTPMzDPM/2bMAGbMM2bMZmbMmWbMzGbM/5nMAJnMM5nMZpnMmZnM
zJnM/8zMAMzMM8zMZszMmczMzMzM///MAP/MM//MZv/Mmf/MzP/M/wD/AAD/MwD/ZgD/mQD/zAD/
/zP/ADP/MzP/ZjP/mTP/zDP//2b/AGb/M2b/Zmb/mWb/zGb//5n/AJn/M5n/Zpn/mZn/zJn//8z/
AMz/M8z/Zsz/mcz/zMz/////AP//M///Zv//mf//zP///wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAKwALAAAAABPADgA
AAj+AP8JHEiwoMGDAgEoXMiwoUOGCCMaNCCx4sGHGDM+tDiRIsePGkOK/CjQI8mIIlOOPMkSoUoA
GGLKnJnyowGTLQmGnMmTpsqcQP/t7MkTo8yGHG8G1ZmRaE+jMZFaxAlUpNOiDolSlbj1pNWrRx8S
lWCzK0exWcFGFas1KU6lEptiSKuW7VibAw0wMCtU7tyGatcCvkq2Itx/DPZe1OiTYeC/g8HyLSiz
61DBCx/bBcsgItyZi+k2zhx4M08JMyUYACCU4GHQBaFidVxa9EyKDDAv7Moztu2wtOtG7qnaAOjV
u/8d/tfb9NPhV3+flkk2N8SJs4M7lf5cu1qKqAX+L8/9ODr0o6MVlsdQ0uf49dvP/00P87HqkqiX
D0wMvztprNnVF5gEigkUE0Xj3dQffUSpl155BOKEQWIdGbegbgICF2B5id1nIGIFCpSYheVlCJmD
jW34WGIUGqhXgiTW5l93M67IokcY3ESVjiWimOJoNQZ2o4Hs6bdXjGD9ByCQKqp15EDsKVeQXuRp
5uOSugUpGUFRSukakkkqORtwVy4oYUlU7dWbeWL6RKaJC1JW0pRqynRkfG3iWWZ/JsWk3I4x5qUn
nINeOFNnH3rpGnN+UuYfoQ16t2BhfuqnHGyOPmhlnnwyN6dBvYGqZZicwofap6LKtBiNm+55oY6K
CB3I15WlBghpeWhKFBOiKGUoaaS/4kqSXhb5WiuGtwbGEq9xyTaoq8qyNNlAjLEZrFpLFevXo8eO
lm2zznKb7JusfdtruLaOu5G553JHrrXXsQtutZqKKy9JL+Xb0LT3MqVvvv2e9a++AQs88E8Fa3vw
SjmxVm5VCzvE7kJLRSyxuQpla7FU3wYEADs=
}



set yfish_r {
R0lGODlhTwA4APcAAAAAAAAAMwAAZgAAmQAAzAAA/zMAADMAMzMAZjMAmTMAzDMA/2YAAGYAM2YA
ZmYAmWYAzGYA/5kAAJkAM5kAZpkAmZkAzJkA/8wAAMwAM8wAZswAmcwAzMwA//8AAP8AM/8AZv8A
mf8AzP8A/wAzAAAzMwAzZgAzmQAzzAAz/zMzADMzMzMzZjMzmTMzzDMz/2YzAGYzM2YzZmYzmWYz
zGYz/5kzAJkzM5kzZpkzmZkzzJkz/8wzAMwzM8wzZswzmcwzzMwz//8zAP8zM/8zZv8zmf8zzP8z
/wBmAABmMwBmZgBmmQBmzABm/zNmADNmMzNmZjNmmTNmzDNm/2ZmAGZmM2ZmZmZmmWZmzGZm/5lm
AJlmM5lmZplmmZlmzJlm/8xmAMxmM8xmZsxmmcxmzMxm//9mAP9mM/9mZv9mmf9mzP9m/wCZAACZ
MwCZZgCZmQCZzACZ/zOZADOZMzOZZjOZmTOZzDOZ/2aZAGaZM2aZZmaZmWaZzGaZ/5mZAJmZM5mZ
ZpmZmZmZzJmZ/8yZAMyZM8yZZsyZmcyZzMyZ//+ZAP+ZM/+ZZv+Zmf+ZzP+Z/wDMAADMMwDMZgDM
mQDMzADM/zPMADPMMzPMZjPMmTPMzDPM/2bMAGbMM2bMZmbMmWbMzGbM/5nMAJnMM5nMZpnMmZnM
zJnM/8zMAMzMM8zMZszMmczMzMzM///MAP/MM//MZv/Mmf/MzP/M/wD/AAD/MwD/ZgD/mQD/zAD/
/zP/ADP/MzP/ZjP/mTP/zDP//2b/AGb/M2b/Zmb/mWb/zGb//5n/AJn/M5n/Zpn/mZn/zJn//8z/
AMz/M8z/Zsz/mcz/zMz/////AP//M///Zv//mf//zP///wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAKwALAAAAABPADgA
AAj+AP8JHEiwoMGDCBMqXJgwQACGEBu2mEixIsWHESNinJgRosUWGAd+vNjxoMN/ASiWRJhyZAuC
LjmuNKlyJsGWMWHGfBlypcOKNgXuBCp057+XPkXWnDm04kOcQ20+tMi0KVCoTU9mnEq0I9amRa2C
7KkwJFWvP8WCPKp2rUauSyOCbLuWLlKGWs9qXPs1Ztq2W8PGLauyr8u/gCGe/IjXItysdgeb3Kg3
4cfHQw2LJWuZcWfGmh1HdtpQqWeDhlFiHm2Vs2rBXW/6hT0S8WaUjn9yNjowNFLIkXEXJp3XqO2R
tBmzpoq1YObbbA/7vt28+HKSxq/LhEpW+0XNq4H+OxbYUqvp65SRR1e7nmTBp+nRJ3drt7373j29
33VJvr79lGQBOJ9/9m0X3GVu9WeWdgt6Np16TglYFEo6LdfgWQ96llt6uy1GYIG/BbeeedEF6CGB
OYEIlnAJhoWaQxmON995iUFV4V34sYZRagNGJRiNBr2k44A0stejTDkOqVmRYjFZmYpG8gallECd
5mRiVIoI5UEpHsmielN2eRhC/DmXU2j9jQYiiTdKRiSaRxpVm0JgmokcnGHStVCddjKXpX4MWcml
hmICGuiTgxJlXJ5WyYUoanMZKB2jKx4a20ItpalejF16dOmeSM52nJ4ZPWpZSlfyxKmpdH4Kam9D
Z646kWuWIunojrFqWRKrdF5JIV20OorjrvNdmFlQpiHLUZ3QIRudszw9KZqMzipV7Xc96fZli9WK
1K2Lzr0XrLMBAQA7
}


set rfish {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}

set rfish_r {
R0lGODlhTwA4APcAAAAAAAAAMwAAZgAAmQAAzAAA/zMAADMAMzMAZjMAmTMAzDMA/2YAAGYAM2YA
ZmYAmWYAzGYA/5kAAJkAM5kAZpkAmZkAzJkA/8wAAMwAM8wAZswAmcwAzMwA//8AAP8AM/8AZv8A
mf8AzP8A/wAzAAAzMwAzZgAzmQAzzAAz/zMzADMzMzMzZjMzmTMzzDMz/2YzAGYzM2YzZmYzmWYz
zGYz/5kzAJkzM5kzZpkzmZkzzJkz/8wzAMwzM8wzZswzmcwzzMwz//8zAP8zM/8zZv8zmf8zzP8z
/wBmAABmMwBmZgBmmQBmzABm/zNmADNmMzNmZjNmmTNmzDNm/2ZmAGZmM2ZmZmZmmWZmzGZm/5lm
AJlmM5lmZplmmZlmzJlm/8xmAMxmM8xmZsxmmcxmzMxm//9mAP9mM/9mZv9mmf9mzP9m/wCZAACZ
MwCZZgCZmQCZzACZ/zOZADOZMzOZZjOZmTOZzDOZ/2aZAGaZM2aZZmaZmWaZzGaZ/5mZAJmZM5mZ
ZpmZmZmZzJmZ/8yZAMyZM8yZZsyZmcyZzMyZ//+ZAP+ZM/+ZZv+Zmf+ZzP+Z/wDMAADMMwDMZgDM
mQDMzADM/zPMADPMMzPMZjPMmTPMzDPM/2bMAGbMM2bMZmbMmWbMzGbM/5nMAJnMM5nMZpnMmZnM
zJnM/8zMAMzMM8zMZszMmczMzMzM///MAP/MM//MZv/Mmf/MzP/M/wD/AAD/MwD/ZgD/mQD/zAD/
/zP/ADP/MzP/ZjP/mTP/zDP//2b/AGb/M2b/Zmb/mWb/zGb//5n/AJn/M5n/Zpn/mZn/zJn//8z/
AMz/M8z/Zsz/mcz/zMz/////AP//M///Zv//mf//zP///wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAKwALAAAAABPADgA
AAj+AP8JHEiwoMGDCBMqXJgwQACGEAmuWfOnosWLGC9GjPhwI8OJFCuGzIhxpEWPBh3+64jSIMiL
JkmKJNkyZc2CL2HKLLnz5sqOIIOCRLhGoFCdPJPSbMnyT8inQQ9O/FeUYsyYTjNizfrn5kOuE50O
lXr0qtazJEP+9PjwZdioLo9ytYi17s6wf1hudCt2atygdJXORCvz5UaVOYWSzTk4MFLBd4tCBAoW
rkTAjxtrdryTrl+FlKGOHSg389zNqDtTXIgYbN/LmE2bJdxZJ2ijeK2KpNoXL+TZkGuLVJswMUyq
uu/+Tiu84j+YxBcnH/78NG3rW7diHKj1s0CguoH+a98MHHpt7mm9k846vrxv7IXHdxWoer5e+eQF
l2/OfybZ2rNBxVlq/QFoH0EB4BcgZ/sVKNxqKSmY1EgUBmedg4EdlKCBSFWYX4MYTtSRXhvW1yGD
g01HoGklFaXXQCUqd2JjT80EooXUIYighDPmN+CFN4qF3EoFxRhfj/D9aFeL2Q314ntHpijblDhC
uV1cDtaoJJUsemalc6Qxxp+WPpb5Y5QnSYShlFu2iSOTEKq5JplJmmlefy5d+KBm7r2Jn0Z5mqQi
c3WeFqSeS+FkqFgm9ukmoZ0Vx56NvBU2oKAsyvflSS8aNSl7yFnpIZ+Z7imTpMlZdZlSmF56XXqW
iUr1qaqrouiqbH9itVB4lBY5aqt2Mmpimgrxyp5kMBq36KOeARhdsbPmiFOqmS35aosRyRUesrCR
eiaim863l3FQEeUtgV8K9axHqb7llLnLroioRuK2pK5i/wE7r7xg+jTtR+5pGqm//mJ2KKIEJwzY
VQJnlPDDuEH5J6AQVxzqxFdarPHGHHfs8ccgh8zQiypxHBAAADs=
}


# -----------------------------------------------------
# Create the canvas and the leaves in the background. 
# ------------------------------------------------------

canvas .c -height 600 -width 600 \
		-background black
pack .c


set im [image create photo -data $leaf \
	-format GIF -gamma 1 \
	-height 200 -width 16 -palette 5/5/4]

.c create image 50 500 -image $im -tag leaf -anchor center

set im [image create photo -data $leaf2 \
		-format GIF -gamma 1 \
		-height 300 -width 24 -palette 5/5/4]
.c create image 100 500 -image $im -tag leaf \
		-anchor center


set im [image create photo -data $leaf6 \
		-format GIF -gamma 1 \
		-height 200 -width 16 -palette 5/5/4]
.c create image 125 500 -image $im -tag leaf \
		-anchor center

set im [image create photo -data $leaf6 \
		-format GIF -gamma 1 \
		-height 200 -width 16 -palette 5/5/4]
.c create image 160 500 -image $im -tag leaf \
		-anchor center

set im [image create photo -data $leaf \
		-format GIF -gamma 1 \
	-height 200 -width 16 -palette 5/5/4]
.c create image 215 500 -image $im -tag leaf \
		-anchor center

set im [image create photo -data $leaf5 \
	-format GIF -gamma 1 \
	-height 175 -width 120 -palette 5/5/4]
.c create image 285 525 -image $im -tag leaf \
	-anchor center

set im [image create photo -data $leaf5 \
		-format GIF -gamma 1 \
		-height 175 -width 120 -palette 5/5/4]
.c create image 400 525 -image $im -tag leaf \
		-anchor center

set im [image create photo -data $leaf \
		 -format GIF -gamma 1 \
		 -height 200 -width 16 -palette 5/5/4]
.c create image 415 500 -image $im -tag leaf \
		-anchor center

set im [image create photo -data $leaf4 \
		-format GIF -gamma 1 \
		-height 300 -width 24 -palette 5/5/4]
.c create image 500 500 -image $im -tag leaf \
		-anchor center


set im [image create photo -data $leaf \
		-format GIF -gamma 1 \
		-height 200 -width 16 -palette 5/5/4]
.c create image 550 500 -image $im -tag leaf \
		-anchor center


# ------------------------------------------------------
# Create and move the fish. The procedure is called 
# for each fish because each fish is placed at 
# different location and moves at a different speed. 
# ------------------------------------------------------


make_fish $gfish 700 300 g
make_fish $rainfish 750 50 rain
make_fish $bfish 600 100 b
make_fish $yfish 600 420 y
make_fish $rfish 700 500 re
make_fish $ofish 800 320 o
make_fish $gfish_r -200 100 gr
make_fish $ofish_r -150 320 or
make_fish $rainfish_r 0 50 rainr
make_fish $bfish_r -100 140 br
make_fish $yfish_r -200 430 yr
make_fish $rfish_r 0 450 rr


move_fish  g     300 700 "$gfish"    700 300
move_fish  gr    200 800 "$gfish_r" -200 100
move_fish  rain  175 750 "$rainfish" 750 50
move_fish  y     260 600 "$yfish"    600 420 
move_fish  b     300 600 "$bfish"    600 100
move_fish  re    400 700 "$rfish"    700 500
move_fish  o     200 800 "$ofish"    800 320
move_fish  or    250 850 "$ofish_r" -150 320
move_fish  rainr 500 800 "$rainfish_r" 0 50
move_fish  br    400 800 "$bfish_r"  -100 140
move_fish  yr    450 900 "$yfish_r"  -200 430
move_fish  rr    250 800 "$rfish_r"  0 450
move_fish  y     200 600 "$yfish"  600 420
 
# -------------------------------------------------
# Place some bubbles 
# --------------------------------------------------

bubbling 620 275 300
bubbling 620 450 400



